## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  eval = "dplyr" %in% rownames(installed.packages())
)

## ----setup--------------------------------------------------------------------
library(ftExtra)

## -----------------------------------------------------------------------------
ft <- iris[1:2, ] %>% flextable
ft

## -----------------------------------------------------------------------------
ft %>% split_header()

## -----------------------------------------------------------------------------
ft %>% split_header(sep = "e")

## -----------------------------------------------------------------------------
ft %>% span_header()

